@@ -846,6 +846,8 @@ static const gchar * const named_channel_allowed_properties[] = {
     NULL
 };
 
+/* not advertised in foreach_channel_class - can only be requested with
+ * RequestChannel, not with CreateChannel/EnsureChannel */
 static const gchar * const anon_channel_allowed_properties[] = {
     NULL
 };
@@ -858,21 +860,16 @@ gabble_media_factory_foreach_channel_class (TpChannelManager *manager,
 {
   GHashTable *table = g_hash_table_new_full (g_str_hash, g_str_equal,
       NULL, (GDestroyNotify) tp_g_value_slice_free);
-  GValue *value, *handle_type_value;
+  GValue *value;
 
   value = tp_g_value_slice_new (G_TYPE_STRING);
   g_value_set_static_string (value, TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA);
   g_hash_table_insert (table, TP_IFACE_CHANNEL ".ChannelType", value);
 
-  handle_type_value = tp_g_value_slice_new (G_TYPE_UINT);
-  /* no uint value yet - we'll change it for each channel class */
-  g_hash_table_insert (table, TP_IFACE_CHANNEL ".TargetHandleType",
-      handle_type_value);
+  value = tp_g_value_slice_new (G_TYPE_UINT);
+  g_value_set_uint (value, TP_HANDLE_TYPE_CONTACT);
+  g_hash_table_insert (table, TP_IFACE_CHANNEL ".TargetHandleType", value);
 
-  g_value_set_uint (handle_type_value, TP_HANDLE_TYPE_NONE);
-  func (manager, table, anon_channel_allowed_properties, user_data);
-
-  g_value_set_uint (handle_type_value, TP_HANDLE_TYPE_CONTACT);
   func (manager, table, named_channel_allowed_properties, user_data);
 
   g_hash_table_destroy (table);
@@ -950,13 +947,8 @@ gabble_media_factory_requestotron (TpChannelManager *manager,
   switch (handle_type)
     {
     case TP_HANDLE_TYPE_NONE:
-      if (handle != 0)
-        {
-          g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
-              "TargetHandle must be zero or omitted if TargetHandleType is "
-              "NONE");
-          goto error;
-        }
+      /* already checked by TpBaseConnection */
+      g_assert (handle == 0);
 
       if (require_target_handle)
         {
@@ -975,10 +967,8 @@ gabble_media_factory_requestotron (TpChannelManager *manager,
       break;
 
     case TP_HANDLE_TYPE_CONTACT:
-      if (!tp_handle_is_valid (
-            tp_base_connection_get_handles (conn, TP_HANDLE_TYPE_CONTACT),
-            handle, &error))
-        goto error;
+      /* validity already checked by TpBaseConnection */
+      g_assert (handle != 0);
 
       if (tp_channel_manager_asv_has_unknown_properties (request_properties,
               media_channel_fixed_properties, named_channel_allowed_properties,
